@@ -2,7 +2,7 @@
 import re
 from typing import Optional, Union, Dict
 import pandas as pd  # type: ignore
-from dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
+from receipt_parser.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
 
 
 class Normalizer:
