@@ -5,14 +5,17 @@ and normalization product descriptions.
 from typing import Union, Optional, Dict
 import pandas as pd  # type: ignore
 try:
-    from . import Finder
-    from . import Normalizer
+    from receipt_parser.finder import Finder
+    from receipt_parser.normalizer import Normalizer
 except ImportError:
     from finder import Finder
     from normalizer import Normalizer
 except ModuleNotFoundError:
     from .finder import Finder
     from .normalizer import Normalizer
+    
+import os
+import wget
 
 
 # pylint: disable=too-few-public-methods
@@ -44,6 +47,14 @@ class RuleBased:
     """
 
     def __init__(self, pathes: Optional[Dict[str, str]] = None):
+        print('TEST')
+        print('LS\n', os.listdir())
+        
+        print('\n\nWGET')
+        url = "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/blacklist.csv"
+        wget.download(url, 'lol.csv')
+        print('\n\nWGET DONE')
+        
         pathes = pathes or {}
 
         self.norm = Normalizer(pathes)
